![](https://vignette.wikia.nocookie.net/horrormovies/images/8/8a/Psycho.jpg/revision/latest/top-crop/width/360/height/450?cb=20150415212637)
# pyscores2
Python API to ship strip theory code Scores2
[This notebook](https://github.com/martinlarsalbert/pyscores2/blob/master/docs/notebooks/01_run_scores2.ipynb) shows how this works. 
